@@ -1,10 +1,22 @@
 # -*- coding: utf-8 -*-
-
+#
+#  Copyright (c) 2010—2012 Andrey Mikhailenko and contributors
+#
+#  This file is part of Argh.
+#
+#  Argh is free software under terms of the GNU Lesser
+#  General Public License version 3 (LGPLv3) as published by the Free
+#  Software Foundation. See the file README for copying conditions.
+#
+"""
+Utilities
+~~~~~~~~~
+"""
 import argparse
 
 
 def get_subparsers(parser, create=False):
-    """Returns the :class:`argparse._SupParsersAction` instance for given
+    """Returns the :class:`argparse._SubParsersAction` instance for given
     :class:`ArgumentParser` instance as would have been returned by
     :meth:`ArgumentParser.add_subparsers`. The problem with the latter is that
     it only works once and raises an exception on the second attempt, and the
